@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use base qw(Net::Amazon::Property);
 
-__PACKAGE__->make_accessor($_) for qw(title publisher binding isbn 
+__PACKAGE__->make_accessor($_) for qw(publisher binding isbn 
     dewey_decimal numpages edition ean publication_date);
 __PACKAGE__->make_array_accessor($_) for qw(authors);
 
@@ -37,8 +37,6 @@ sub init_via_xmlref {
     $self->binding($ref->{Binding});
     $self->dewey_decimal($ref->{DeweyDecimalNumber});
     $self->numpages($ref->{NumberOfPages});
-    $self->title($ref->{Title});
-    $self->Title($ref->{Title});
     $self->publisher($ref->{Publisher});
     $self->isbn($ref->{ISBN});
     $self->edition($ref->{Edition});
@@ -51,8 +49,6 @@ sub init_via_xmlref {
     $self->year($year);
 
     $self->publication_date($ref->{PublicationDate});
-
-    $self->ReleaseDate($ref->{ReleaseDate});
 }
 
 ##################################################
@@ -74,7 +70,7 @@ sub as_string {
     return join('/', @a) . ", " .
       '"' . $self->title . '"' . ", " .
       $self->year . ", " .
-      $self->OurPrice . ", " .
+      $self->_best_effort_price() . ", " .
       $self->ASIN;
 }
 
@@ -144,6 +140,9 @@ Returns the number of pages.
 
 Returns the Dewey decimal number, this is for non-fiction only.
 
+This method is deprecated (2011-10-28) as it does not appear to be returned by
+Amazon any more.
+
 =item publication_date()
 
 Returns the publication date.
@@ -168,8 +167,6 @@ data.
 Check out L<Net::Amazon::Property> for all-purpose accessors, like
 C<year>, C<OurPrice>, C<ListPrice>, etc.
 
-=head1 SEE ALSO
-
 =head1 AUTHOR
 
 Mike Schilli, E<lt>m@perlmeister.comE<gt>
